import request from '@/utils/request'

/**
 * 获取用户列表
 * @param {Object} params 查询参数
 * @returns {Promise}
 */
export function getUserList(params) {
  return request({
    url: '/users',
    method: 'get',
    params
  })
}

/**
 * 获取用户详情
 * @param {string|number} id 用户ID
 * @returns {Promise}
 */
export function getUserById(id) {
  return request({
    url: `/users/${id}`,
    method: 'get'
  })
}

/**
 * 创建用户
 * @param {Object} data 用户数据
 * @returns {Promise}
 */
export function createUser(data) {
  return request({
    url: '/users',
    method: 'post',
    data
  })
}

/**
 * 更新用户
 * @param {string|number} id 用户ID
 * @param {Object} data 用户数据
 * @returns {Promise}
 */
export function updateUser(id, data) {
  return request({
    url: `/users/${id}`,
    method: 'put',
    data
  })
}

/**
 * 删除用户
 * @param {string|number} id 用户ID
 * @returns {Promise}
 */
export function deleteUser(id) {
  return request({
    url: `/users/${id}`,
    method: 'delete'
  })
}

/**
 * 批量删除用户
 * @param {Array} ids 用户ID数组
 * @returns {Promise}
 */
export function batchDeleteUsers(ids) {
  return request({
    url: '/users/batch',
    method: 'delete',
    data: { ids }
  })
}

/**
 * 重置用户密码
 * @param {string|number} id 用户ID
 * @param {string} newPassword 新密码
 * @returns {Promise}
 */
export function resetUserPassword(id, newPassword) {
  return request({
    url: `/users/${id}/password/reset`,
    method: 'post',
    data: { newPassword }
  })
}

/**
 * 启用/禁用用户
 * @param {string|number} id 用户ID
 * @param {boolean} enabled 是否启用
 * @returns {Promise}
 */
export function toggleUserStatus(id, enabled) {
  return request({
    url: `/users/${id}/status`,
    method: 'put',
    data: { enabled }
  })
}